<?php

date_default_timezone_set('UTC');

$OLD_PWD = $_SERVER['PWD'];
chdir(dirname($argv[0]));

if ($argv[0] === './pre-install.php' || $_SERVER['PWD'] !== $OLD_PWD) {
  $LIB_DIR = $_SERVER['PWD'];
} else {
  $LIB_DIR = getcwd();
}

if (count($argv) > 1 && $argv[1] === '--non-interactive') {
  $NO_PROMPT = true;
} else {
  $NO_PROMPT = false;
}

// have all the configured values available to this script.
// Load the configuration. This will put a $CONFIG array in scope that will
include_once 'configure.php';

// path specific to this feed app version
$APP_DIR = dirname($LIB_DIR);
$HTDOCS_DIR = $APP_DIR . DIRECTORY_SEPARATOR . 'htdocs';
$CONF_DIR = $APP_DIR . DIRECTORY_SEPARATOR . 'conf';
$HTTPD_CONF_FILE = $CONF_DIR . DIRECTORY_SEPARATOR . 'httpd.conf';

$FEED_PATH = $CONFIG['FEED_PATH'] . '/' . $CONFIG['API_VERSION'];
$FDSN_PATH = $CONFIG['FDSN_PATH'];
$SEARCH_PATH = $CONFIG['SEARCH_PATH'];

$storage_directory = $CONFIG['storage_directory'];
$storage_url = $CONFIG['storage_url'];



// write apache configuration
$HTTPD_CONF = '
## This configuration is auto generated by pre-install
## Manual changes will be overwritten
##

########################################################
# FeedApp: Realtime feeds and search
# Primary contact : Jeremy Fee <jmfee@usgs.gov>
# Secondary contact : Eric Martinez <emartinez@usgs.gov>
########################################################

### PRODUCT SEARCH APP

RewriteEngine on



## EQ Search URL Hijacking

# Only ever offered for v1.0, so just need to redirect that version
RewriteRule ^' . $SEARCH_PATH . '$ ' . $SEARCH_PATH . '/ [R=301]
RewriteRule ^' . $SEARCH_PATH . '/$ ' . $FEED_PATH . '/search.php [L,PT]
RewriteRule ^' . $SEARCH_PATH . '/(js|css|lib)/(.*) ' . $FEED_PATH .
    '/$1/$2 [L,PT]

## END: EQ Search URL Hijacking


# forbid cache busting query strings
RewriteCond %{QUERY_STRING} ^.+
RewriteRule ^' . $FEED_PATH . '/(summary|detail)/.* - [F,L]

# detail is EVENTID.FORMAT
RewriteRule ^' . $FEED_PATH . '/detail/([^\./]+)\.([^/\.]+)$ ' . $FEED_PATH .
    '/detail.php?eventid=$1&format=$2 [L,PT]
# summary is PARAMS.FORMAT
RewriteRule ^' . $FEED_PATH . '/summary/([^/]+)\.([^/\.]+)$ ' . $FEED_PATH .
    '/summary.php?params=$1&format=$2 [L,PT]


# fdsn event webservice
RewriteRule ^' . $FDSN_PATH . '$ ' . $FDSN_PATH . '/ [R=301,L]
RewriteRule ^' . $FDSN_PATH . '/query\.([^/]*)$ ' . $FEED_PATH .
    '/fdsn.php?method=query&format=$1 [L,QSA,PT]
RewriteRule ^' . $FDSN_PATH . '/([^/]*)$ ' . $FEED_PATH .
    '/fdsn.php?method=$1 [L,QSA,PT]

Alias ' . $FEED_PATH . ' ' . $HTDOCS_DIR . '
Alias ' . $storage_url . ' ' . $storage_directory . '

<Directory ' . $HTDOCS_DIR . '>
  Order allow,deny
  Allow from all
</Directory>

<Directory ' . $storage_directory . '>
  Order allow,deny
  Allow from all
  ExpiresActive on
  ExpiresDefault "access plus 10 years"

  # prevent php execution in product contents
  <IfModule mod_php5.c>
    php_flag engine off
  </IfModule>

  # only allow GET access
  <LimitExcept GET>
    Order allow,deny
    Deny from all
  </LimitExcept>

  # block query strings
  RewriteCond %{QUERY_STRING} ^.+
  RewriteRule .* - [F,L]
</Directory>

<Location ' . $FEED_PATH . '/>
  SetEnv APP_URL_PATH ' . $FEED_PATH . '
  SetEnv APP_WEB_DIR ' . $HTDOCS_DIR . '
  ExpiresActive on
  ExpiresDefault "access plus 1 days"

  # only allow GET access
  <LimitExcept GET>
    Order allow,deny
    Deny from all
  </LimitExcept>
</Location>

<Location ' . $FDSN_PATH . '/>
  # only allow GET access
  <LimitExcept GET>
    Order allow,deny
    Deny from all
  </LimitExcept>
</Location>
';


file_put_contents($HTTPD_CONF_FILE, $HTTPD_CONF);


?>
